@@ -15,7 +15,40 @@ from collections import defaultdict
 from itertools import zip_longest
 #from colorama import Fore, Back, Style
 from colors import color
-from qic import commandline
+
+class commandline :
+    @staticmethod
+    def qx(cmd, merge=False, debug=False, exitonerror=False, hidepwd=False, pwdmark="") :
+        if type(cmd) is not list :
+            if type(cmd) is str :
+                cmd = cmd.split()
+            else :
+                raise Exception("cmd must be a list or a string.")
+        cmdmasked = list()
+        if hidepwd :
+            i=0
+            while i < len(cmd) :
+                if cmd[i] in ['-'+c for c in pwdmark] :
+                    cmdmasked.append(cmd[i])
+                    if i+1 < len(cmd) :
+                        cmdmasked.append("******")
+                    i+=2
+                else :
+                    cmdmasked.append(cmd[i])
+                    i+=1
+        if debug :
+            print("# cmd=[{}]".format(" ".join(cmdmasked or cmd)))
+        with subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.subprocess.STDOUT if merge else subprocess.PIPE) as p :
+            out, err = p.communicate()
+            out = out and out.decode().rstrip()
+            err = err and err.decode().rstrip()
+            if debug :
+                print("# stdout=[{}]".format(out or ""))
+                print("# stderr=[{}]".format(err or ""))
+                print("# rtcode=[{}]".format(p.returncode))
+            if p.returncode != 0 and exitonerror :
+                sys.exit(p.returncode)
+            return (p.returncode, out, err)
 
 
 def prepare_table(xjson, xheader=None):
